@@ -30,15 +30,15 @@ class LkeapClient(AbstractClient):
         """#### 接口功能
 
         调用接口，发起一次对话请求。
-        如需使用OpenAI兼容接口， 请参考文档：[OpenAI 兼容接口](https://cloud.tencent.com/document/product/1772/115968)
+        如需使用OpenAI兼容接口， 请参考文档：[Deepseek OpenAI对话接口](https://cloud.tencent.com/document/product/1772/115969)
 
         #### 已支持的模型
         - DeepSeek-V3（model 参数值为**deepseek-v3**）
             - DeepSeek-V3为671B参数MoE模型，在百科知识、数学推理等多项任务上优势突出，评测成绩在主流榜单中位列开源模型榜首。
-            - 支持64K上下文长度，最大支持8K输出长度。
+            - 支持64K上下文长度，最大输入56k，最大输出8k（不含思维链）。
         - DeepSeek-R1（model 参数值为**deepseek-r1**）
             - DeepSeek-R1为671B模型，使用强化学习训练，推理过程包含大量反思和验证，思维链长度可达数万字。 该系列模型在数学、代码以及各种复杂逻辑推理任务上推理效果优异，并为用户展现了完整的思考过程。
-            - 支持64K上下文长度，最大支持8K输出长度。
+            -  支持64K上下文长度，最大输入56k，最大输出8k（不含思维链）。
 
         #### 计费说明
         - 限时免费
@@ -49,7 +49,7 @@ class LkeapClient(AbstractClient):
          ![image](https://cdn.xiaowei.qq.com/static/lke/deekseep-token0212.png)
 
         ### Openai兼容协议接口
-        知识引擎原子能力大模型对话 API 兼容了 OpenAI 的接口规范，这意味着您可以直接使用 OpenAI 官方提供的 SDK 来调用大模型对话接口。您仅需要将 base_url 和 [api_key](https://cloud.tencent.com/document/product/1772/115970) 替换成相关配置，不需要对应用做额外修改，即可无缝将您的应用切换到相应的大模型。请参考文档：[OpenAI 兼容接口](https://cloud.tencent.com/document/product/1772/115968)。
+        知识引擎原子能力大模型对话 API 兼容了 OpenAI 的接口规范，这意味着您可以直接使用 OpenAI 官方提供的 SDK 来调用大模型对话接口。您仅需要将 base_url 和 [api_key](https://cloud.tencent.com/document/product/1772/115970) 替换成相关配置，不需要对应用做额外修改，即可无缝将您的应用切换到相应的大模型。请参考文档：[Deepseek OpenAI对话接口](https://cloud.tencent.com/document/product/1772/115969)。
         > base_url：  https://api.lkeap.cloud.tencent.com/v1
 
         > api_key的获取请参考[API KEY管理](https://cloud.tencent.com/document/product/1772/115970)
@@ -669,7 +669,7 @@ class LkeapClient(AbstractClient):
 
 
     def UploadDoc(self, request):
-        """用于上传文档内容。上传的文档将存储在知识库中，可以通过SearchKnowledge知识库内容检索接口进行检索。
+        """用于上传文档内容。上传的文档将存储在知识库中，可以通过RetrieveKnowledge[知识库内容检索接口](https://cloud.tencent.com/document/product/1772/115349)进行检索。
         使用场景：适用于需要长期存储和检索的文档内容，如产品手册、用户指南等。
 
         :param request: Request instance for UploadDoc.
@@ -693,7 +693,8 @@ class LkeapClient(AbstractClient):
 
 
     def UploadDocRealtime(self, request):
-        """用于上传实时文档内容。实时文档在上传后可以立即通过SearchRealtime进行实时检索，适用于在会话中对文档进行问答的场景。
+        """用于上传实时文档内容。
+        实时文档在上传后可以立即通过SearchRealtime进行实时检索，适用于在会话中对文档进行问答的场景。
 
         :param request: Request instance for UploadDocRealtime.
         :type request: :class:`tencentcloud.lkeap.v20240522.models.UploadDocRealtimeRequest`
